@@ -12,8 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from pathlib import Path
 from collections.abc import Callable
+from pathlib import Path
 
 from mostlyai.sdk._local.execution.step_create_model_report import create_report
 from mostlyai.sdk.domain import Generator, ModelType, StepCode
@@ -30,7 +30,9 @@ def execute_step_create_data_report(
 ):
     # create model report and return metrics
     create_report(
-        step_code=StepCode.create_data_report,
+        step_code=StepCode.create_data_report_tabular
+        if model_type == ModelType.tabular
+        else StepCode.create_data_report_language,
         generator=generator,
         workspace_dir=workspace_dir,
         model_type=model_type,
